""" Unit tests for e10_version """
import logging
import re

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from .e10_version import get_e10_version
from .e10_eth0_config import get_eth0_config


def try_e10_version():
    try:
        return get_e10_version()
    except:
        return None

log = logging.getLogger(__name__)

ipv4addr = re.compile(r"[1-2]?\d?\d\.[1-2]?\d?\d\.[1-2]?\d?\d\.[1-2]?\d?\d")


class Test_e10_eth0_config(unittest.TestCase):
    """Unit tests for e10_eth0_config."""
    # pylint: disable=R0904

    @unittest.skipIf(try_e10_version() is None, "Not supported unless testing on an E10")
    def test_get_returns_dict(self):
        """get_eth0_config shall return a dictionary."""
        cfg = get_eth0_config()

        self.assertTrue(isinstance(cfg, dict))

    @unittest.skipIf(try_e10_version() is None, "Not supported unless testing on an E10")
    def test_get_returns_dhcp(self):
        """get_eth0_config shall return a boolean indicating dhcp."""
        cfg = get_eth0_config()

        self.assertTrue(isinstance(cfg['dhcp'], bool))

    @unittest.skipIf(try_e10_version() is None, "Not supported unless testing on an E10")
    def test_get_returns_ip_addr(self):
        """get_eth0_config shall return a string indicating ip address."""
        cfg = get_eth0_config()

        self.assertTrue(ipv4addr.match(cfg['ip_addr']) is not None)

    @unittest.skipIf(try_e10_version() is None, "Not supported unless testing on an E10")
    def test_get_returns_netmask(self):
        """get_eth0_config shall return a string indicating netmask."""
        cfg = get_eth0_config()

        self.assertTrue(ipv4addr.match(cfg['netmask']) is not None)

    @unittest.skipIf(try_e10_version() is None, "Not supported unless testing on an E10")
    def test_get_returns_gateway(self):
        """get_eth0_config shall return a string indicating gateway."""
        cfg = get_eth0_config()

        self.assertTrue(ipv4addr.match(cfg['gateway']) is not None)
