# E10 Utilities

These utilities wrap:
* Discovering the version of E10 your code is running on
* Discovering/Editing the eth0 configuration (via /etc/network/interfaces)
* Controlling LED B

These utilities were originally developed for use with the E10 1.0 and Python 2.6.

## CAVEAT LECTOR
This is (mostly) legacy code. Some of it has tests, some of the tests have to run on an E10.

# Getting Started

## TL;DR

Make a virtualenv if you want.
```bash
mkvirtualenv foo
```

Install from artifactory.
```bash
pip install -i https://artifactory.synapse-wireless.com/artifactory/pypi-synapse-public e10utils
```

## Examples - E10 Version

```python
>>> from e10utils import e10_version
>>> e10_version.get_e10_version()
'1.99.0'
```

## Examples - E10 eth0 config

```python
>>> from e10utils import e10_eth0_config
>>> e10_eth0_config.get_eth0_config()
{'ip_addr': '10.82.15.41', 'hostname': 'e10', 'netmask': '255.255.255.0', 'mac_addr': '00:1c:2c:4c:71:d6', 'dhcp': True, 'gateway': '10.82.15.1'}

>>> e10_utils.set_eth0_config(False, '10.82.15.211', '255.255.255.0', '10.82.15.1')
>>> e10_utils.get_eth0_config()
{'dhcp': False, 'netmask': '255.255.255.0', 'ip_addr': '10.82.15.211', 'gateway': '10.82.15.1'}
>>> e10_utils.set_eth0_config(True)
>>> e10_utils.get_eth0_config()
{'dhcp': True, 'netmask': '255.255.255.0', 'ip_addr': '10.82.15.7', 'gateway': '10.82.15.1'}
```

Note: set_eth0_config calls get_e10_version to make sure you're on an E10 before
    changing /etc/network/interfaces, and may therefore raise a NotAnE10Exception
    if you're not on an E10.

## Examples - E10 LED B control

```python
>>> from e10utils import e10_led
>>> e10_led.set_e10_led_b_red()
>>> e10_led.set_e10_led_b_green()
>>> e10_led.set_e10_led_b_yellow()
>>> e10_led.set_e10_led_b_off()
```
