import logging
import os

from .e10_version import get_e10_version, NotAnE10Exception

log = logging.getLogger(__name__)

LED_OFF = 0
LED_RED = 1
LED_GREEN = 2
LED_YELLOW = 3

E10_1_0 = "1.0.0"
E10_1_1 = "1.1.0"

try:
    E10_VER = get_e10_version()
except NotAnE10Exception:
    E10_VER = None

log.debug("E10 Version for LED Control: %r", E10_VER)

class E10SysClassLedControl(object):

    def red_off(self):
        os.system("echo 0 > /sys/class/leds/redled/brightness")

    def red_on(self):
        os.system("echo 1 > /sys/class/leds/redled/brightness")

    def green_off(self):
        os.system("echo 0 > /sys/class/leds/greenled/brightness")

    def green_on(self):
        os.system("echo 1 > /sys/class/leds/greenled/brightness")

class E10BinLedControl(object):

    def red_off(self):
        os.system("/usr/bin/redled 0")

    def red_on(self):
        os.system("/usr/bin/redled 1")

    def green_off(self):
        os.system("/usr/bin/greenled 0")

    def green_on(self):
        os.system("/usr/bin/greenled 1")

_LED_CONTROL = None

if E10_VER == E10_1_1:
    # Only 1.1 E10s use /usr/bin bits to control the leds
    _LED_CONTROL = E10BinLedControl()
elif E10_VER:
    # 1.0 E10s only have sys class, and that works on 2.0 E10s as well.
    _LED_CONTROL = E10SysClassLedControl()

def set_e10_led_b_off():
    if _LED_CONTROL:
        _LED_CONTROL.red_off()
        _LED_CONTROL.green_off()

def set_e10_led_b_red():
    if _LED_CONTROL:
        _LED_CONTROL.red_on()
        _LED_CONTROL.green_off()


def set_e10_led_b_green():
    if _LED_CONTROL:
        _LED_CONTROL.red_off()
        _LED_CONTROL.green_on()


def set_e10_led_b_yellow():
    if _LED_CONTROL:
        _LED_CONTROL.red_on()
        _LED_CONTROL.green_on()


def set_e10_led_b(state):
    if state == LED_OFF:
        set_e10_led_b_off()
    elif state == LED_RED:
        set_e10_led_b_red()
    elif state == LED_GREEN:
        set_e10_led_b_green()
    elif state == LED_YELLOW:
        set_e10_led_b_yellow()
    else:
        log.error("Invalid LED state: %r", state)
